@@ -24,11 +24,6 @@ my @optionals = (
       provides default attribute values, and which can be encrypted with
       gpg2. If you do not intend to make use of the identity file,
       Config::Identity is not needed.
-EOD
-    __any( 'Browser::Open'		=> <<'EOD' ),
-      This module is being phased in as the only supported way to
-      display web-based help. If you intend to leave the 'webcmd'
-      attribute false, this module is not needed.
 EOD
     __any( 'Time::HiRes'		=> <<'EOD' ),
       This module is used for more precise throttling of Space Track
@@ -37,15 +32,65 @@ EOD
 EOD
 );
 
-my %core = map { $_ => 1 } qw{ Time::HiRes };
+sub make_optional_modules_tests {
+    eval {
+	require Test::Without::Module;
+	1;
+    } or return;
+    my $dir = 'xt/author/optionals';
+    -d $dir
+	or mkdir $dir
+	or die "Can not create $dir: $!\n";
+    opendir my $dh, 't'
+	or die "Can not access t/: $!\n";
+    while ( readdir $dh ) {
+	m/ \A [.] /smx
+	    and next;
+	m/ [.] t \z /smx
+	    or next;
+	my $fn = "$dir/$_";
+	-e $fn
+	    and next;
+	print "Creating $fn\n";
+	open my $fh, '>:encoding(utf-8)', $fn
+	    or die "Can not create $fn: $!\n";
+	print { $fh } <<"EOD";
+package main;
+
+use strict;
+use warnings;
+
+use Test::More 0.88;
+
+use lib qw{ inc };
+
+use My::Module::Recommend;
+
+BEGIN {
+    eval {
+	require Test::Without::Module;
+	Test::Without::Module->import(
+	    My::Module::Recommend->optionals() );
+	1;
+    } or plan skip_all => 'Test::Without::Module not available';
+}
+
+do 't/$_';
+
+1;
+
+__END__
+
+# ex: set textwidth=72 :
+EOD
+    }
+    closedir $dh;
+
+    return $dir;
+}
 
 sub optionals {
-    # As of Test::Builder 1.302190 (March 2 2022) Time::HiRes is needed
-    # by Test::Builder, which is used by Test::More. It's a core module,
-    # so it OUGHT to be available, though there are known downstream
-    # packagers who strip core modules. Sigh. This is the reason I'm
-    # stripping it here rather than removing it completely.
-    return ( grep { ! $core{$_} } map { $_->modules() } @optionals );
+    return ( map { $_->modules() } @optionals );
 }
 
 sub recommend {
@@ -95,6 +140,24 @@ mechanism is not used because we find its output on the Draconian side.
 
 This class supports the following public methods:
 
+=head2 make_optional_modules_tests
+
+ My::Module::Recommend->make_optional_modules_tests()
+
+This static method creates the optional module tests. These are stub
+files in F<xt/author/optionals/> that use C<Test::Without::Module> to
+hide all the optional modules and then invoke the normal tests in F<t/>.
+The aim of these tests is to ensure that we get no test failures if the
+optional modules are missing.
+
+This method is idempotent; that is, it only creates the directory and
+the individual stub files if they are missing.
+
+On success this method returns the name of the optional tests directory.
+If C<Test::Without::Module> can not be loaded this method returns
+nothing. If the directory or any file can not be created, an exception
+is thrown.
+
 =head2 optionals
 
  say for My::Module::Recommend->optionals();
@@ -113,9 +176,7 @@ module, and any possible problems with installing it.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-SpaceTrack>,
-L<https://github.com/trwyant/perl-Astro-SpaceTrack/issues/>, or in
-electronic mail to the author.
+L<http://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -123,11 +184,11 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2026 by Thomas R. Wyant, III
+Copyright (C) 2010-2017 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
-of the licenses in the files F<LICENSE-Artistic> and F<LICENSE-GPL>.
+of the licenses in the directory LICENSES.
 
 This program is distributed in the hope that it will be useful, but
 without any warranty; without even the implied warranty of
